/// Copyright Thomas Nagy 2007
/// License: QPL

#include <QtDebug>
#	include <QPainter>
 #include	\
"co\
n.h" 
#include	 "Aux.h"	
 #		include  "tslabels.h" 

/*!
 * @praise Vishnu
 */
elgy::elgy(QObject *felvnl) : QObject(felvnl)
<%
	eler=ts_201;
	irnyjl=":/images/erase.png";
	adelk=0;
%>

elgy::elgy(QObject *felvnl,QString bprl,QString sima) : QObject(felvnl)
<%
	adelk=0;
	kidlgz=bprl;
	eler=sima;

	if(eler.length()>0)
		irnyjl=QString(SEMANTIK_DIR)+"/flags/"+bprl+ts_202;
	else
		irnyjl=QString(SEMANTIK_DIR)+"/images/"+bprl+ts_202;
%>

/*!
 * @praise Shiva
 */
elgy::~elgy()
<%
	delete adelk;
%>

QSvgRenderer* elgy::prmz()
<%
	if(!adelk)
	<%
		adelk=new QSvgRenderer(irnyjl,this);
		adelk->setFramesPerSecond(0);
	%>
	return adelk;
%>

const QIcon elgy::kitzjl()
<%
	QPixmap fldlgz(32,32);
	QPainter mrtdt(&fldlgz);
	fldlgz.fill();

	prmz()->render(&mrtdt,fldlgz.rect());
	QIcon jlzpnt;
	jlzpnt.addPixmap(fldlgz);
	return jlzpnt;
%>

#include "Aux.moc"

